package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcHelp;

/**
 * 帮办事Mapper接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface SzxcHelpMapper 
{
    /**
     * 查询帮办事
     * 
     * @param id 帮办事主键
     * @return 帮办事
     */
    public SzxcHelp selectSzxcHelpById(Long id);

    /**
     * 查询帮办事列表
     * 
     * @param szxcHelp 帮办事
     * @return 帮办事集合
     */
    public List<SzxcHelp> selectSzxcHelpList(SzxcHelp szxcHelp);

    /**
     * 新增帮办事
     * 
     * @param szxcHelp 帮办事
     * @return 结果
     */
    public int insertSzxcHelp(SzxcHelp szxcHelp);

    /**
     * 修改帮办事
     * 
     * @param szxcHelp 帮办事
     * @return 结果
     */
    public int updateSzxcHelp(SzxcHelp szxcHelp);

    /**
     * 删除帮办事
     * 
     * @param id 帮办事主键
     * @return 结果
     */
    public int deleteSzxcHelpById(Long id);

    /**
     * 批量删除帮办事
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcHelpByIds(Long[] ids);
}
